<?php
/*
Plugin Name: OpenAI MultiSite Article Generator
Description: Genera articoli con OpenAI sia in multisite (1–10 articoli, super admin può selezionare qualsiasi sito) sia in single site (admin vede il proprio). Prompt opzionale (se mancante, usa il titolo). Possibilità di prompt strutturato e scelta se pubblicare o tenere in bozza. Categoria e stato correttamente selezionabili.
Version: 4.1
Author: Seo Wp
Author URI: https://seowp.it/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

if ( ! defined( 'ABSPATH' ) ) exit;

// Costanti plugin
define( 'OAG_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'OAG_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

// Variabile globale per i log
$log_messages = [];

/**
 * Funzione di log che usa gmdate() e esc_html
 */
function oag_log( $message ) {
    global $log_messages;
    $time = gmdate('[Y-m-d H:i:s] ');
    // Escappiamo il messaggio
    $log_messages[] = esc_html( $time . $message );
}

// Se multisite, menu in network admin. Se single site, in admin.
if ( is_multisite() ) {
    // Link impostazioni solo ai super admin
    add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'oag_add_plugin_settings_link_multisite' );
    function oag_add_plugin_settings_link_multisite( $links ) {
        if ( is_super_admin() ) {
            // Escappiamo l’HTML
            $settings_link = '<a href="' . esc_url( '/wp-admin/network/admin.php?page=openai-generator' ) . '">Impostazioni</a>';
            $links[]       = $settings_link;
        }
        return $links;
    }

    // Menu solo in network admin se super admin
    add_action( 'network_admin_menu', 'oag_add_admin_menu_multisite' );
    function oag_add_admin_menu_multisite() {
        if ( is_super_admin() ) {
            add_menu_page(
                'OpenAI Generator',
                'OpenAI Generator',
                'manage_network_options',
                'openai-generator',
                'oag_options_page'
            );
            add_submenu_page(
                'openai-generator',
                'Documentazione',
                'Documentazione',
                'manage_network_options',
                'openai-generator-docs',
                'oag_docs_page'
            );
        }
    }

} else {
    // Single site: menu + link in Impostazioni
    add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'oag_add_plugin_settings_link_singlesite' );
    function oag_add_plugin_settings_link_singlesite( $links ) {
        if ( current_user_can('manage_options') ) {
            $settings_link = '<a href="' . esc_url( admin_url( 'options-general.php?page=openai-generator' ) ) . '">Impostazioni</a>';
            $links[]       = $settings_link;
        }
        return $links;
    }

    add_action( 'admin_menu', 'oag_add_admin_menu_singlesite' );
    function oag_add_admin_menu_singlesite() {
        add_options_page(
            'OpenAI Generator',
            'OpenAI Generator',
            'manage_options',
            'openai-generator',
            'oag_options_page'
        );
    }
}

// Sottopagina "Documentazione"
function oag_docs_page() {
    ?>
    <div class="wrap">
        <h1><?php echo esc_html( 'Documentazione del Plugin' ); ?></h1>
        <p>
            <?php echo esc_html( 'Questo plugin permette di generare articoli con OpenAI sia in Single Site che in MultiSite.' ); ?><br>
            <strong>MultiSite</strong>: <?php echo esc_html( 'il super admin imposta la chiave API e seleziona il sito. Admin di singolo sito non vede la chiave né sceglie siti.' ); ?><br>
            <strong>Single Site</strong>: <?php echo esc_html( "l'admin vede la chiave API nelle Impostazioni." ); ?>
        </p>
        <ol style="margin-left:20px;">
            <li><strong><?php echo esc_html( 'Installazione' ); ?></strong>: <?php echo esc_html( 'attiva il plugin (a livello di network se sei in multisite).' ); ?></li>
            <li><strong><?php echo esc_html( 'Titoli e Prompt' ); ?></strong>: <?php echo esc_html( 'puoi inserirli manualmente o generarli in bulk. Se un prompt manca, usa il titolo come fallback.' ); ?></li>
            <li><strong><?php echo esc_html( 'Prompt Strutturato' ); ?></strong>: <?php echo esc_html( 'capitoli, sezioni, paragrafi, parole/paragrafo, bold, tabelle.' ); ?></li>
            <li><strong><?php echo esc_html( 'Anti-duplicazione titoli' ); ?></strong>: <?php echo esc_html( 'Se i titoli generati >= numero articoli, ogni articolo riceve un titolo univoco.' ); ?></li>
        </ol>
        <p><?php echo esc_html( 'Sostituisci questo link con quello del tuo video:' ); ?></p>
        <p>
            <a href="<?php echo esc_url( 'https://example.com/video-tutorial.mp4' ); ?>" target="_blank" rel="noopener noreferrer">
                <?php echo esc_html( 'Guarda il video tutorial' ); ?>
            </a>
        </p>
    </div>
    <?php
}

// Pagina impostazioni/generazione articoli
function oag_options_page() {
    global $log_messages;

    if ( isset( $_POST['oag_generate_articles'] ) ) {
        oag_log('Form submitted for article generation.');
        oag_generate_articles_from_admin();
    }

    $is_multisite   = is_multisite();
    $is_super_admin = $is_multisite && is_super_admin();
    $can_set_key    = ( $is_multisite && $is_super_admin ) || ( ! $is_multisite && current_user_can('manage_options') );

    $get_key_fn = $is_multisite ? 'get_site_option' : 'get_option';
    $key_val    = $get_key_fn('oag_api_key');
    ?>
    <style>
    .wrap {
        background: #fafafa;
        max-width: 1000px;
        margin: 20px auto;
        padding: 20px;
        font-family: Arial, sans-serif;
        border: 1px solid #ddd;
        border-radius: 8px;
    }
    .wrap h1 {
        font-size: 24px;
        margin-bottom: 15px;
        color: #333;
    }
    .wrap form label {
        display: block;
        margin: 10px 0 5px;
        font-weight: bold;
        color: #444;
    }
    .wrap form input[type="text"],
    .wrap form input[type="number"],
    .wrap form select,
    .wrap form textarea {
        width: 80%;
        margin-bottom: 12px;
        padding: 6px;
        border: 1px solid #ccc;
        border-radius: 4px;
        background: #fff;
        color: #333;
        box-sizing: border-box;
    }
    .wrap form textarea {
        min-height: 60px;
    }
    .wrap .button {
        margin-top: 10px;
    }
    .debug-log {
        background-color: #f1f1f1;
        padding: 10px;
        border: 1px solid #ccc;
        margin-top: 20px;
        border-radius: 4px;
    }
    fieldset.article-field {
        border:1px solid #ddd;
        padding:10px;
        margin-bottom:10px;
        border-radius:4px;
    }
    .article-field legend {
        font-weight:bold;
        margin-left:10px;
    }
    .quick-btns {
        margin-top: 10px;
    }
    .quick-btns .button {
        margin-right: 10px;
    }
    .helper {
        background: #fff7dd;
        border: 1px solid #ffeeaa;
        border-radius: 4px;
        padding: 10px;
        margin-bottom: 15px;
        color: #555;
    }
    .struct-container {
        background: #f9f9f9;
        border: 1px solid #ddd;
        padding: 10px;
        border-radius: 4px;
        margin-bottom: 20px;
    }
    .struct-container label {
        display: inline-block;
        margin-right: 10px;
        margin-top: 10px;
    }
    </style>

    <div class="wrap">
        <h1><?php echo esc_html( 'OpenAI Article Generator' ); ?></h1>

        <div class="helper">
            <p><?php echo esc_html( 'Genera 1–10 articoli. Se il prompt è vuoto, userà il titolo. Puoi creare titoli in bulk e/o un prompt strutturato.' ); ?></p>
        </div>

        <form method="post">
            <?php if ( $can_set_key ) : ?>
                <!-- Chiave API -->
                <label for="oag_api_key"><?php echo esc_html( 'OpenAI API Key:' ); ?></label>
                <input type="text" name="oag_api_key" id="oag_api_key" value="<?php echo esc_attr( $key_val ); ?>" size="50" required>
            <?php endif; ?>

            <?php if ( $is_multisite ) : ?>
                <?php if ( $is_super_admin ) : ?>
                    <br>
                    <label for="oag_blog_id"><?php echo esc_html( 'Seleziona Sito del Network:' ); ?></label>
                    <select name="oag_blog_id" id="oag_blog_id" required onchange="updateCategories(this.value)">
                        <?php
                        $sites = get_sites();
                        foreach ( $sites as $site ) {
                            // Escapare blog_id e blogname
$bid      = esc_attr( $site->blog_id );
$blogname = esc_html( get_blog_option( $site->blog_id, 'blogname' ) );

// Invece di fare un singolo echo con concatenazione, facciamo:
printf(
    '<option value="%1$s">%2$s</option>',
    esc_attr( $site->blog_id ),
    esc_html( get_blog_option( $site->blog_id, 'blogname' ) )
);


                        }
                        ?>
                    </select>
                <?php else : ?>
                    <input type="hidden" name="oag_blog_id" value="<?php echo esc_attr( get_current_blog_id() ); ?>">
                <?php endif; ?>
            <?php else : ?>
                <input type="hidden" name="oag_blog_id" value="<?php echo esc_attr( get_current_blog_id() ); ?>">
            <?php endif; ?>

            <br><br>

            <label for="oag_article_count"><?php echo esc_html( 'Numero di articoli da generare (1–10):' ); ?></label>
            <input type="number" name="oag_article_count" id="oag_article_count" min="1" max="10" value="1" required onchange="updatePromptFields(this.value)">

            <label><?php echo esc_html( 'Seleziona Categoria:' ); ?></label>
            <div id="category-container"></div>

            <label for="oag_post_status"><?php echo esc_html( 'Stato degli Articoli:' ); ?></label>
            <select name="oag_post_status" id="oag_post_status" style="width:200px;">
                <option value="publish" selected><?php echo esc_html( 'Pubblica' ); ?></option>
                <option value="draft"><?php echo esc_html( 'Bozza' ); ?></option>
            </select>

            <hr>
            <h2><?php echo esc_html( 'Titoli in Bulk' ); ?></h2>
            <p style="margin:0 0 10px;color:#666;"><?php echo esc_html( 'Il numero di titoli da generare corrisponderà al numero di articoli.' ); ?></p>
            <label for="bulk_title_topic"><?php echo esc_html( 'Tema generale dei titoli:' ); ?></label>
            <input type="text" id="bulk_title_topic" placeholder="<?php echo esc_attr( 'Es: Tecnologia, Cucina, Marketing...' ); ?>">

            <button type="button" class="button" onclick="generateBulkTitles()">
                <?php echo esc_html( 'Genera Titoli Diversi' ); ?>
            </button>
            <p style="margin:0 0 10px;color:#666;"><?php echo esc_html( 'Se i titoli generati >= numero articoli, non ci saranno duplicati.' ); ?></p>

            <hr>
            <h2><?php echo esc_html( 'Specifica Struttura (Opzionale)' ); ?></h2>
            <p style="margin:0 0 10px;color:#666;">
                <?php echo esc_html( 'Imposta capitoli, sezioni, paragrafi, parole, e l\'uso di grassetti/tabelle. Poi clicca \"Genera Prompt Strutturato\" per popolare il Prompt Globale.' ); ?>
            </p>

            <div class="struct-container">
                <label><?php echo esc_html( 'Capitoli (1-10):' ); ?><br>
                <input type="number" id="struct_chapters" min="1" max="10" value="2"></label>

                <label><?php echo esc_html( 'Sezioni (1-10):' ); ?><br>
                <input type="number" id="struct_sections" min="1" max="10" value="2"></label>

                <label><?php echo esc_html( 'Paragrafi (1-10):' ); ?><br>
                <input type="number" id="struct_paragraphs" min="1" max="10" value="3"></label>

                <label><?php echo esc_html( 'Parole/Paragrafo (50-300):' ); ?><br>
                <input type="number" id="struct_words" min="50" max="300" value="100"></label>

                <br>
                <label>
                    <input type="checkbox" id="struct_bold" checked>
                    <?php echo esc_html( 'Includi Grassetti?' ); ?>
                </label>
                <br>
                <label>
                    <input type="checkbox" id="struct_tables">
                    <?php echo esc_html( 'Includi Tabelle?' ); ?>
                </label>
                <br><br>
                <button type="button" class="button" onclick="buildStructuredPrompt()">
                    <?php echo esc_html( 'Genera Prompt Strutturato' ); ?>
                </button>
            </div>

            <h2><?php echo esc_html( 'Prompt Globale (opzionale)' ); ?></h2>
            <p style="margin:0 0 10px;color:#666;">
                <?php echo esc_html( 'Scrivi qui un prompt da applicare in blocco a tutti gli articoli (se non già specificato). Se un articolo non ha prompt, userà il titolo come fallback.' ); ?>
            </p>
            <textarea id="bulk_prompt" rows="3" placeholder="<?php echo esc_attr( 'Inserisci (o genera) un prompt da applicare a tutti' ); ?>"></textarea>

            <div class="quick-btns">
                <button type="button" class="button" onclick="applyBulkPromptToAll()">
                    <?php echo esc_html( 'Applica Prompt a tutti' ); ?>
                </button>
            </div>

            <hr>
            <!-- Container per i singoli articoli -->
            <div id="prompt-fields"></div>

            <input type="submit" name="oag_generate_articles" class="button button-primary" value="<?php echo esc_attr( 'Genera Articoli' ); ?>">
        </form>

        <h2><?php echo esc_html( 'Debug Log' ); ?></h2>
        <div class="debug-log">
            <?php
            // Escappiamo ogni riga di log
            foreach ( $log_messages as $log ) {
                echo '<p>' . esc_html( $log ) . '</p>';
            }
            ?>
        </div>

        <script>
        const isMultisite = <?php echo is_multisite() ? 'true' : 'false'; ?>;
        const isSuperAdmin = <?php echo (is_multisite() && is_super_admin()) ? 'true' : 'false'; ?>;
        const defaultBlogId = <?php echo (int) get_current_blog_id(); ?>;

        document.addEventListener('DOMContentLoaded', function() {
            if(isMultisite && isSuperAdmin) {
                <?php if( is_multisite() && is_super_admin() ) {
                    $allSites = get_sites();
                    if(!empty($allSites)) {
                        // Escappiamo $allSites[0]->blog_id
$first_blog_id = (int) $allSites[0]->blog_id;
echo 'updateCategories(' . esc_js( $first_blog_id ) . ');';
                    }
                } ?>
            } else {
                updateCategories(defaultBlogId);
            }
        });

        function updateCategories(blogId) {
            const baseUrl = '<?php echo esc_url( admin_url('admin-ajax.php') ); ?>';
            const url = baseUrl + '?action=oag_get_categories&blog_id=' + encodeURIComponent(blogId);
            fetch(url)
                .then(response => response.text())
                .then(data => {
                    document.getElementById('category-container').innerHTML = data;
                })
                .catch(error => console.error('Errore:', error));
        }

        function updatePromptFields(count) {
            const container = document.getElementById('prompt-fields');
            container.innerHTML = '';
            for (let i = 0; i < count; i++) {
                container.innerHTML += `
<fieldset class="article-field">
<legend>Articolo ${i+1}</legend>
<label>Titolo:</label>
<input type="text" name="oag_title_${i}" placeholder="Titolo per articolo ${i+1}" />
<br><br>
<label>Prompt (opzionale):</label>
<textarea name="oag_prompt_${i}" rows="3"></textarea>
</fieldset>
`;
            }
        }

        function generateBulkTitles(){
            const topic = document.getElementById('bulk_title_topic').value || 'varie';
            const count = document.querySelector('[name="oag_article_count"]').value;
            const baseUrl = '<?php echo esc_url( admin_url('admin-ajax.php') ); ?>';
            const url = baseUrl + '?action=oag_generate_bulk_titles&topic=' + encodeURIComponent(topic)
                      + '&qty=' + encodeURIComponent(count);

            fetch(url)
                .then(res => res.json())
                .then(data => {
                    if(data.success && Array.isArray(data.titles)){
                        distributeTitlesNoDuplicates(data.titles, count);
                        alert('Titoli generati e assegnati in modo casuale!');
                    } else {
                        alert('Errore nella generazione dei titoli: ' + (data.msg || 'Unknown error'));
                    }
                })
                .catch(err => {
                    console.error(err);
                    alert('Errore di rete nella generazione dei titoli.');
                });
        }

        function distributeTitlesNoDuplicates(titles, count){
            function titleFieldSelector(i){
                return document.querySelector(`[name="oag_title_${i}"]`);
            }

            if(titles.length < count) {
                for(let i=0; i<count; i++) {
                    let randomIndex = Math.floor(Math.random() * titles.length);
                    let field = titleFieldSelector(i);
                    if(field) field.value = titles[randomIndex];
                }
                return;
            }

            shuffleArray(titles);
            for(let i=0; i<count; i++) {
                let field = titleFieldSelector(i);
                if(field) field.value = titles[i];
            }
        }

        function shuffleArray(array) {
            for (let i = array.length - 1; i > 0; i--) {
                const j = Math.floor(Math.random() * (i + 1));
                [array[i], array[j]] = [array[j], array[i]];
            }
        }

        function buildStructuredPrompt(){
            const chapters = parseInt(document.getElementById('struct_chapters').value || 1);
            const sections = parseInt(document.getElementById('struct_sections').value || 1);
            const paragraphs = parseInt(document.getElementById('struct_paragraphs').value || 1);
            const words = parseInt(document.getElementById('struct_words').value || 100);
            const bold = document.getElementById('struct_bold').checked;
            const tables = document.getElementById('struct_tables').checked;

            let prompt = `Crea un articolo con:\n- ${chapters} capitoli\n- ${sections} sezioni\n- ${paragraphs} paragrafi per sezione\n- ~${words} parole per paragrafo\n`;

            if(bold) {
                prompt += '- Usa grassetti dove rilevante\n';
            }
            if(tables) {
                prompt += '- Includi almeno una tabella, se possibile\n';
            }

            prompt += '\nMantenere coerenza e struttura.';
            document.getElementById('bulk_prompt').value = prompt;
        }

        function applyBulkPromptToAll(){
            const bulk = document.getElementById('bulk_prompt').value;
            if(!bulk){
                alert('Nessun prompt globale da applicare!');
                return;
            }
            const count = document.querySelector('[name="oag_article_count"]').value;
            for(let i=0; i<count; i++) {
                const ta = document.querySelector(`[name="oag_prompt_${i}"]`);
                if(ta) ta.value = bulk;
            }
            alert('Prompt globale applicato a tutti gli articoli!');
        }
        </script>
    </div>
    <?php
}

/**
 * AJAX: Carichiamo le categorie con escaping
 */
add_action('wp_ajax_oag_get_categories', 'oag_get_categories_callback');
function oag_get_categories_callback() {
    if( ! isset( $_GET['blog_id'] ) ){
        wp_die();
    }
    $blog_id = (int) $_GET['blog_id'];

    if( is_multisite() ) {
        switch_to_blog( $blog_id );
    }

    wp_dropdown_categories( array(
        'taxonomy'   => 'category',
        'hide_empty' => false,
        'name'       => 'oag_category',
        'id'         => 'oag_category_dropdown',
        'orderby'    => 'name',
        'hierarchical' => true
    ) );

    if( is_multisite() ) {
        restore_current_blog();
    }
    wp_die();
}

/**
 * AJAX: genera titoli con GPT
 */
add_action('wp_ajax_oag_generate_bulk_titles', 'oag_generate_bulk_titles_callback');
function oag_generate_bulk_titles_callback() {
    $topic = isset( $_GET['topic'] ) ? sanitize_text_field( wp_unslash( $_GET['topic'] ) ) : 'varie';
    $qty   = isset( $_GET['qty'] ) ? intval( $_GET['qty'] ) : 1;

    $is_multisite = is_multisite();
    $api_key = $is_multisite ? get_site_option( 'oag_api_key' ) : get_option( 'oag_api_key' );

    if( ! $api_key ){
        wp_send_json( array( 'success' => false, 'msg' => 'Missing API Key' ) );
    }

    $prompt = "Genera $qty titoli di articoli in italiano, brevi, sul tema: $topic. Devono essere vari e creativi.";

    $response = wp_remote_post(
        'https://api.openai.com/v1/chat/completions',
        array(
            'timeout' => 60,
            'headers' => array(
                'Content-Type'  => 'application/json',
                'Authorization' => 'Bearer ' . sanitize_text_field( $api_key ),
            ),
            'body' => wp_json_encode( array(
                'model'    => 'gpt-4-turbo',
                'messages' => array(
                    array( 'role' => 'system', 'content' => 'Sei un assistente che genera titoli di articoli in italiano.' ),
                    array( 'role' => 'user',   'content' => $prompt )
                ),
                'max_tokens' => 500,
            ) ),
        )
    );

    if( is_wp_error( $response ) ){
        wp_send_json( array( 'success' => false, 'msg' => $response->get_error_message() ) );
    }

    $body = json_decode( wp_remote_retrieve_body( $response ), true );
    if( ! isset( $body['choices'][0]['message']['content'] ) ){
        wp_send_json( array( 'success' => false, 'msg' => 'API Response missing content' ) );
    }

    $text  = $body['choices'][0]['message']['content'];
    $lines = preg_split( '/\r?\n/', $text );
    $lines = array_filter( $lines, function( $l ){ return trim( $l ) !== ''; } );

    $titles = array();
    foreach( $lines as $line ){
        $line = preg_replace( '/^[0-9]+\)?\.\s*/', '', wp_unslash( $line ) );
        $titles[] = trim( $line );
    }

    if( empty( $titles ) ){
        wp_send_json( array( 'success' => false, 'msg' => 'No titles found after parsing' ) );
    }

    wp_send_json( array( 'success' => true, 'titles' => $titles ) );
}

/**
 * Genera articoli
 */
function oag_generate_articles_from_admin() {
    $is_multisite   = is_multisite();
    $is_super_admin = ( $is_multisite && is_super_admin() );

    // Aggiorniamo la chiave (solo super admin multi o admin single)
    if( $is_multisite && $is_super_admin && isset( $_POST['oag_api_key'] ) ){
        $api_key = sanitize_text_field( wp_unslash( $_POST['oag_api_key'] ) );
        update_site_option( 'oag_api_key', $api_key );
        oag_log( 'API Key updated by super admin (multisite).' );
    }
    else if( ! $is_multisite && current_user_can( 'manage_options' ) && isset( $_POST['oag_api_key'] ) ){
        $api_key = sanitize_text_field( wp_unslash( $_POST['oag_api_key'] ) );
        update_option( 'oag_api_key', $api_key );
        oag_log( 'API Key updated by single-site admin.' );
    }
    else {
        // Leggiamo la chiave esistente
        $api_key = $is_multisite ? get_site_option( 'oag_api_key' ) : get_option( 'oag_api_key' );
    }

    $count     = isset($_POST['oag_article_count']) ? intval( $_POST['oag_article_count'] ) : 1;
    $category  = isset($_POST['oag_category'])      ? intval( $_POST['oag_category'] )      : 0;
    $post_stat = isset($_POST['oag_post_status'])   ? sanitize_text_field( wp_unslash( $_POST['oag_post_status'] ) ) : 'publish';

    $blog_id = get_current_blog_id();
    if( $is_multisite ) {
        if( $is_super_admin && isset( $_POST['oag_blog_id'] ) ){
            $blog_id = (int) $_POST['oag_blog_id'];
        }
    }

    oag_log( 'Starting article generation... count=' . $count . ', blog_id=' . $blog_id . ', category=' . $category . ', status=' . esc_html( $post_stat ) );

    if( $is_multisite ){
        switch_to_blog( $blog_id );
    }

    for ( $i = 0; $i < $count; $i++ ) {
        $title_key   = 'oag_title_' . $i;
        $prompt_key  = 'oag_prompt_' . $i;

        $user_title  = isset( $_POST[ $title_key ] ) ? sanitize_text_field( wp_unslash( $_POST[ $title_key ] ) ) : ( 'Articolo Generato ' . ( $i + 1 ) );
        $user_prompt = isset( $_POST[ $prompt_key ] ) ? sanitize_textarea_field( wp_unslash( $_POST[ $prompt_key ] ) ) : '';

        $final_prompt = $user_prompt ? $user_prompt : $user_title;

        oag_log( 'Article ' . $i . ' => Title: ' . $user_title . ', Prompt: ' . $final_prompt );
        $article_content = oag_generate_article( $api_key, $final_prompt );
        if( is_wp_error( $article_content ) ){
            oag_log( 'Error generating article: ' . $article_content->get_error_message() );
            continue;
        }

        wp_insert_post( array(
            'post_title'    => $user_title,
            'post_content'  => $article_content,
            'post_status'   => $post_stat,
            'post_category' => array( $category )
        ) );
        oag_log( 'Article ' . $i . ' with status=' . $post_stat . ' published successfully.' );
    }

    if( $is_multisite ){
        restore_current_blog();
    }
}

/**
 * Chiamata a OpenAI con escaping
 */
function oag_generate_article( $api_key, $prompt ) {
    oag_log( 'Calling OpenAI API...' );
    $api_key_safe = sanitize_text_field( $api_key );

    $response = wp_remote_post(
        'https://api.openai.com/v1/chat/completions',
        array(
            'timeout' => 60,
            'headers' => array(
                'Content-Type'  => 'application/json',
                'Authorization' => 'Bearer ' . $api_key_safe,
            ),
            'body' => wp_json_encode( array(
                'model'    => 'gpt-4-turbo',
                'messages' => array(
                    array( 'role' => 'system', 'content' => 'Sei un assistente che genera articoli completi.' ),
                    array( 'role' => 'user',   'content' => $prompt )
                ),
                'max_tokens' => 1500,
            ) ),
        )
    );

    if( is_wp_error( $response ) ){
        oag_log( 'API Error: ' . $response->get_error_message() );
        return $response;
    }

    $body = json_decode( wp_remote_retrieve_body( $response ), true );
    // Escappiamo la stampa in log
    oag_log( 'API Response: ' . esc_html( print_r( $body, true ) ) );

    if( isset( $body['choices'][0]['message']['content'] ) ){
        return sanitize_textarea_field( $body['choices'][0]['message']['content'] );
    } else {
        return new WP_Error( 'api_error', 'Errore API' );
    }
}